function [COMES_wrkspc] = ComputeHurwitzStabilityRegion(COMES_wrkspc)
%% define symbolic variables
syms s w x1 x2 real

%% title
disp('% --------------------------------------------------------------- %')
disp('%                   Hurwitz Stability Constraint                  %')
disp('% --------------------------------------------------------------- %')

%% frequency range, i.e., linspace(lowfreq,uppfreq,no_freq_points)

% upper-bound of frequency
prompt = 'Choose a frequency upperbound [rad/s] : ';
answer = input(prompt,'s');
%
uppfreq = str2double(answer);
while isnan(uppfreq) ~= 0
    answer  = input(prompt,'s');
    uppfreq = str2double(answer);
end

% lower-bound of frequency
lowfreq = eps;

% no of grid points
prompt = 'Choose number of frequency points : ';
answer = input(prompt,'s');
%
no_freq_points = str2double(answer);
while isnan(no_freq_points) ~= 0
    answer  = input(prompt,'s');
    no_freq_points = str2double(answer);
end

% frequency range
fr = linspace(lowfreq,uppfreq,no_freq_points);

%% 

% complementary sensitivity function 
T = COMES_wrkspc.TransferFunction.T;

% characteristic polynomial
[N,D] = numden(T); 

%% parameter space computation for Hurwitz stability

% complex root boundary (CRB)
d    = subs(D,'s',j*w);
eqn1 = simplify( real(d) );
eqn2 = simplify( imag(d) );

sol1 = solve(eqn1, eqn2, x1, x2);

sol1_x1_w = subs(sol1.x1,'w',fr);
sol1_x2_w = subs(sol1.x2,'w',fr);

COMES_wrkspc.rbstctrl.HurwitzStability.Solutions.sol1.x1 = double(sol1_x1_w);
COMES_wrkspc.rbstctrl.HurwitzStability.Solutions.sol1.x2 = double(sol1_x2_w);

% real root boundary (RRB)
d    = subs(D,'s',0);

% imaginary root boundary (IRB)
d = subs(expand( D / (s^2) ),'s',inf);

%% 
disp('% --------------------------------------------------------------- %')
disp('%                     Computation Completed                       %')
disp('% --------------------------------------------------------------- %')

%% End of Function