function [COMES_wrkspc] = ComputeMixedSensitivityRegion(COMES_wrkspc)
%% define symbolic variables
syms s w kr ki x1 x2 real

%% mixed sensitivity requirements
disp('% --------------------------------------------------------------- %')
disp('%                   Mixed Sensitivity Constraint                  %')
disp('% --------------------------------------------------------------- %')

%% frequency range

% lower-bound of frequency
prompt = 'Choose a frequency lower-bound [rad/s] : ';
answer = input(prompt,'s');
%
lowfreq = str2double(answer);
while isnan(lowfreq) ~= 0
    answer  = input(prompt,'s');
    lowfreq = str2double(answer);
end

% upper-bound of frequency
prompt = 'Choose a frequency upper-bound [rad/s] : ';
answer = input(prompt,'s');
%
uppfreq = str2double(answer);
while isnan(uppfreq) ~= 0
    answer  = input(prompt,'s');
    uppfreq = str2double(answer);
end

% no of grid points
prompt = 'Choose number of frequency points : ';
answer = input(prompt,'s');
%
no_freq_points = str2double(answer);
while isnan(no_freq_points) ~= 0
    answer         = input(prompt,'s');
    no_freq_points = str2double(answer);
end

% active frequency range
freq = linspace(lowfreq,uppfreq,no_freq_points);

%% Weightining Functions 

disp('% --------------------------------------------------------------- %')
disp('%                 Sensitivity function weight                     %')
disp('% --------------------------------------------------------------- %')
disp('%                  -1         s + w_s * l_s                       %')
disp('%                Ws   = h_s -----------------                     %')
disp('%                             s + w_s * h_s                       %')
disp('% --------------------------------------------------------------- %')

% low frequency bound
prompt = 'Low frequency bound [ls] : ';
answer = input(prompt,'s');
%
ls = str2double(answer);
while isnan(ls) ~= 0
    answer  = input(prompt,'s');
         ls = str2double(answer);
end

% high frequency bound
prompt = 'High frequency bound [hs] : ';
answer = input(prompt,'s');
%
hs = str2double(answer);
while isnan(hs) ~= 0
    answer  = input(prompt,'s');
         hs = str2double(answer);
end

% approximate bandwidth
prompt = 'approximate bandwidth (rad/s) [ws] : ';
answer = input(prompt,'s');
%
ws = str2double(answer);
while isnan(ws) ~= 0
    answer  = input(prompt,'s');
         ws = str2double(answer);
end

% numerator and denumerator of sensitivity function weight
numws = [ 1 ws*hs ];
denws = [ hs hs*ws*ls ]; 

%
COMES_wrkspc.TransferFunction.Ws = poly2sym(numws)/poly2sym(denws);

disp('% --------------------------------------------------------------- %')
disp('%          Complementary sensitivity function weight              %')
disp('% --------------------------------------------------------------- %')
disp('%                             s + w_t * l_t                       %')
disp('%                Wt   = h_t -----------------                     %')
disp('%                             s + w_t * h_t                       %')
disp('% --------------------------------------------------------------- %')

% low frequency bound
prompt = 'Low frequency bound [lt] : ';
answer = input(prompt,'s');
%
lt = str2double(answer);
while isnan(lt) ~= 0
    answer  = input(prompt,'s');
         lt = str2double(answer);
end

% high frequency bound
prompt = 'High frequency bound [ht] : ';
answer = input(prompt,'s');
%
ht = str2double(answer);
while isnan(ht) ~= 0
    answer  = input(prompt,'s');
         ht = str2double(answer);
end

% approximate bandwidth
prompt = 'Approximate bandwidth (rad/s) [wt] : ';
answer = input(prompt,'s');
%
wt = str2double(answer);
while isnan(wt) ~= 0
     answer = input(prompt,'s');
         wt = str2double(answer);
end

% numerator and denumerator of complementary sensitivity function weight
numwt = [ ht ht*wt*lt ];
denwt = [ 1 wt*ht ];

%
COMES_wrkspc.TransferFunction.Wt = poly2sym(numwt)/poly2sym(denwt);

%% plant model
[numg,deng] = numden(COMES_wrkspc.TransferFunction.G);
       numg = sym2poly(numg);
       deng = sym2poly(deng);

%% computation of the controller parameter space 
for index = 1:no_freq_points

    wa = 2*pi*freq(index);
    sa = j*wa;

    G  = polyval(numg,sa)./polyval(deng,sa);
    Gr = real(G);
    Gi = imag(G);
    
    Ws    = polyval(numws,sa)./polyval(denws,sa);
    Wsabs = abs(Ws);

    Wt    = polyval(numwt,sa)./polyval(denwt,sa);
    Wtabs = abs(Wt);

    % theta_s 
    thS_grid = 100;
    thS      = linspace(0,2*pi,thS_grid);
    % 
    [Kr, Ki, solL] = CalcCC(thS,Wsabs,Wtabs,Gr,Gi);
    
    Cw = subs(COMES_wrkspc.TransferFunction.C,'s',sa);

    eqn1 = simplify( real(Cw) ) - kr;
    eqn2 = simplify( imag(Cw) ) - ki;
    %
    sol  = solve(eqn1, eqn2, x1, x2);
    %
    sol_x1 = subs(sol.x1,{'kr','ki'},{Kr,Ki});
    sol_x2 = subs(sol.x2,{'kr','ki'},{Kr,Ki});

    % plot
    plot(sol_x1,sol_x2,'g','linewidth',3)%g

    hold on
    % processing ...
    fprintf('.')
end
% computation completed
fprintf('.\n')
disp('% --------------------------------------------------------------- %')
disp('%                     Computation Completed                       %')
disp('% --------------------------------------------------------------- %')

%% End of Function