function [COMES_wrkspc] = ComputePhaseMarginRegion(COMES_wrkspc)
%% define symbolic variables
syms s w x1 x2 real

%% constant phase margin requirements
disp('% --------------------------------------------------------------- %')
disp('%                    Phase Margin Constraint                      %')
disp('% --------------------------------------------------------------- %')

%% frequency range

% lower-bound of frequency
prompt = 'Choose a frequency lower-bound [rad/s] : ';
answer = input(prompt,'s');
%
lowfreq = str2double(answer);
while isnan(lowfreq) ~= 0
    answer  = input(prompt,'s');
    lowfreq = str2double(answer);
end

% upper-bound of frequency
prompt = 'Choose a frequency upper-bound [rad/s] : ';
answer = input(prompt,'s');
%
uppfreq = str2double(answer);
while isnan(uppfreq) ~= 0
    answer  = input(prompt,'s');
    uppfreq = str2double(answer);
end

% no of grid points
prompt = 'Choose number of frequency points : ';
answer = input(prompt,'s');
%
no_freq_points = str2double(answer);
while isnan(no_freq_points) ~= 0
    answer  = input(prompt,'s');
    no_freq_points = str2double(answer);
end

% active frequency range
freq = linspace(lowfreq,uppfreq,no_freq_points);

%% desired phase margin range

% upper-bound of phase margin
prompt = 'Choose a phase margin (degree) for lower-bound : ';
answer = input(prompt,'s');
%
lowPM  = str2double(answer);
while isnan(lowPM) ~= 0
    answer = input(prompt,'s');
    lowPM  = str2double(answer);
end

% lower-bound of phase margin
prompt = 'Choose a phase margin (degree) for upper-bound : ';
answer = input(prompt,'s');
%
uppPM  = str2double(answer);
while isnan(uppPM) ~= 0
    answer = input(prompt,'s');
    uppPM  = str2double(answer);
end

% number of phase points
prompt       = 'Choose number of phase margin points : ';
answer       = input(prompt,'s');
%
no_pm_points = str2double(answer);
while isnan(no_pm_points) ~= 0
    answer       = input(prompt,'s');
    no_pm_points = str2double(answer);
end

% phase margin range
phi = linspace(lowPM,uppPM,no_pm_points)*pi/180; 

%% compute parameter space region to obtain a desired phase margin

% compute frequency response of loop transfer function
Lfr = simplify(subs(COMES_wrkspc.TransferFunction.L,'s',j*w));
 
for index = 1:length(phi)

    eqn1      = simplify( real(Lfr) ) + cos( phi(index) );
    eqn2      = simplify( imag(Lfr) ) + sin( phi(index) );
    %
    sol       = solve(eqn1,eqn2,x1,x2);
    %
    sol_x1_w  = subs(sol.x1,'w',freq);
    sol_x2_w  = subs(sol.x2,'w',freq);
    
    % convert data to double
    COMES_wrkspc.rbstctrl.PhaseMargin.Solutions.x1(index,:) = double(sol_x1_w);
    COMES_wrkspc.rbstctrl.PhaseMargin.Solutions.x2(index,:) = double(sol_x2_w);
    
    plot(COMES_wrkspc.rbstctrl.PhaseMargin.Solutions.x1(index,:),...
        COMES_wrkspc.rbstctrl.PhaseMargin.Solutions.x2(index,:),'black','Linewidth',2)
    hold on
    % processing ...
    fprintf('.')
end
% computation completed
fprintf('.\n')
disp('% --------------------------------------------------------------- %')
disp('%                     Computation Completed                       %')
disp('% --------------------------------------------------------------- %')

%% End of Function