function [x1_n,x2_n] = PlotDStabilityRegion(COMES_wrkspc)

%% pick a set of controller parameters from the parameter space
try
    close(2)
    [x1_n,x2_n] = ginput(1);
catch
    [x1_n,x2_n] = ginput(1);
end

%%
sigma = COMES_wrkspc.rbstctrl.DStability.Constraints.sigma;
alpha = COMES_wrkspc.rbstctrl.DStability.Constraints.alpha;
R     = COMES_wrkspc.rbstctrl.DStability.Constraints.R;

% characteristic polynomial
[N,D] = numden(COMES_wrkspc.TransferFunction.T);

% characteristic polynomial with numerical values of controller parameters
D_numeric = subs(D,{'x1','x2'},{x1_n,x2_n});

% roots of closed-loop characteristic polynomial
poles = roots( sym2poly(D_numeric) );

% real and imaginary parts of these roots
poles_re = real(poles);
poles_im = imag(poles);

%% plot
% number of data points which are used in this plot
no_data_points = 51;

%
r   = sigma/cos(pi-alpha);
phi = linspace(alpha,2*pi-alpha,no_data_points);

x1  = -sigma.*ones(1,no_data_points);
y1  = linspace(-r*sin(pi-alpha),r*sin(pi-alpha),no_data_points);
%
x2  = linspace(-sigma,-R*cos(pi-alpha),no_data_points);
y2  = linspace(r*sin(pi-alpha),R*sin(pi-alpha),no_data_points);
%
x3  = R.*cos(phi);
y3  = R.*sin(phi);

%
figure()
plot(x1,y1,'r','LineWidth',3)
hold on
plot(x2,y2,'g',x2,-y2,'g','LineWidth',3)
plot(x3,y3,'b','LineWidth',3)

plot(poles_re,poles_im,'mx','LineWidth',3,'MarkerSize',12)
xlabel('Re','FontName','Arial','FontSize',20)
ylabel('Im','FontName','Arial','FontSize',20)
axis equal
sgrid
set(gca,'FontName','Arial','FontSize',20)

%% End of program