function [COMES_wrkspc] = SysInput(COMES_wrkspc)

%% Define symbolic variable
syms s real

%% System model
disp('% --------------------------------------------------------------- %')
disp('%                                                                 %')
disp('%            --------         --------                            %')
disp('%           |        |       |        |                           %')
disp('% --->O---->|  C(s)  |------>|  G(s)  |--------->                 %')
disp('%     ^     |        |       |        |    |                      %')
disp('%     |      --------         --------     |                      %')
disp('%     |                                    |                      %')
disp('%     |               --------             |                      %')
disp('%     |              |        |            |                      %')
disp('%      --------------|  H(s)  |<-----------                       %')
disp('%                    |        |                                   %')
disp('%                     --------                                    %')
disp('%                                                                 %')
disp('% --------------------------------------------------------------- %')

disp('% --------------------------------------------------------------- %')
disp('%                  Plant Transfer Function G(s)                   %')
disp('% --------------------------------------------------------------- %')
% Plant transfer function
prompt = 'Numerator of plant transfer function: ';
answer = input(prompt,'s');
%
num = str2num(answer);
while isempty(num) ~= 0
    answer = input(prompt,'s');
    num  = str2num(answer);
end
%
prompt = 'Denumerator of plant transfer function: ';
answer = input(prompt,'s');
%
den = str2num(answer);
while isempty(den) ~= 0
    answer = input(prompt,'s');
    den  = str2num(answer);
end
%
G = poly2sym(num,s)/poly2sym(den,s);

disp('% --------------------------------------------------------------- %')
disp('%                 Sensor Transfer Function H(s)                   %')
disp('% --------------------------------------------------------------- %')
% Sensor transfer function
prompt = 'Numerator of sensor transfer function: ';
answer = input(prompt,'s');
%
num = str2num(answer);
while isempty(num) ~= 0
    answer = input(prompt,'s');
    num  = str2num(answer);
end
%
prompt = 'Denumerator of sensor transfer function: ';
answer = input(prompt,'s');
%
den = str2num(answer);
while isempty(den) ~= 0
    answer = input(prompt,'s');
    den  = str2num(answer);
end
%
H = poly2sym(num,s)/poly2sym(den,s);

disp('% --------------------------------------------------------------- %')
disp('%                Controller Transfer Function C(s)                %')
disp('% --------------------------------------------------------------- %')
disp('%                                                                 %')
disp('% Controller consists of two unknown variables, i.e., x1 and x2.  %')
disp('% Example: Num: [ sym(x1,real) sym(x2,real) ]                     %')
disp('%          Den: [ 1 0 ]                                           %')
disp('%                                                                 %')
disp('% --------------------------------------------------------------- %')
% Controller transfer function
prompt = 'Numerator of controller transfer function: ';
answer = input(prompt,'s');
%
num = str2num(answer);
% while isempty(num) ~= 0
%     answer = input(prompt,'s');
%     num  = str2num(answer);
% end
%
prompt = 'Denumerator of controller transfer function: ';
answer = input(prompt,'s');
%
den = str2num(answer);
% while isempty(den) ~= 0
%     answer = input(prompt,'s');
%     den  = str2num(answer);
% end
%
C = poly2sym(num,s)/poly2sym(den,s);

% Loop transfer function 
L = G*C;

% Sensitivity transfer function
S = collect( simplify( expand( 1/(1+L*H) ) ) );

% Complementary transfer function
T = collect( simplify( expand( L/(1+L*H) ) ) );

%% output of function
COMES_wrkspc.TransferFunction.C = C;
COMES_wrkspc.TransferFunction.G = G;
COMES_wrkspc.TransferFunction.H = H;
COMES_wrkspc.TransferFunction.L = L;
COMES_wrkspc.TransferFunction.S = S;
COMES_wrkspc.TransferFunction.T = T;

%% End of Function